#
# spec file for package weave
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           weave
Version:        2.6.2
Release:        bp156.3.14
Summary:        Pod Network Add-On
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/weaveworks/weave
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
Source2:        weave-daemonset-k8s-1.11.yaml
# This package contains the content of a container image, so yes,
# this includes the home directory and the database.
Source3:        weave-rpmlintrc
Patch0:         Makefile.diff
Patch1:         disable-iptables-setup.patch
BuildRequires:  binutils-gold
BuildRequires:  libpcap-devel
BuildRequires:  golang(API) >= 1.12
ExcludeArch:    s390 %{ix86}

%description
Weave Net creates a virtual network that connects containers across multiple
hosts and enables their automatic discovery. With Weave Net, portable
microservices-based applications consisting of multiple containers can run
anywhere: on one host, multiple hosts or even across cloud providers and data
centers. Applications use the network just as if the containers were all plugged
into the same network switch, without having to configure port mappings,
ambassadors or links.

%package kube
Summary:        Pod Network Add-On
Group:          System/Management
Requires:       /usr/sbin/modprobe
Requires:       bind-utils
Requires:       ca-certificates-mozilla
Requires:       conntrack-tools
Requires:       curl
Requires:       iproute2
Requires:       ipset
Requires:       iptables

%description kube
Weave Net creates a virtual network that connects containers across multiple
hosts and enables their automatic discovery. With Weave Net, portable
microservices-based applications consisting of multiple containers can run
anywhere: on one host, multiple hosts or even across cloud providers and data
centers. Applications use the network just as if the containers were all plugged
into the same network switch, without having to configure port mappings,
ambassadors or links.

This package contains the files to be included into the weave-kube container image

%package npc
Summary:        Pod Network Add-On
Group:          System/Management
Requires:       ipset
Requires:       iptables
Requires:       ulogd
Requires:       ulogd-pcap

%description npc
Weave Net creates a virtual network that connects containers across multiple
hosts and enables their automatic discovery. With Weave Net, portable
microservices-based applications consisting of multiple containers can run
anywhere: on one host, multiple hosts or even across cloud providers and data
centers. Applications use the network just as if the containers were all plugged
into the same network switch, without having to configure port mappings,
ambassadors or links.

This package contains the files to be included into the weave-kube container image

%package k8s-yaml
Summary:        Kubernetes yaml file to run weave container
Group:          System/Management
BuildArch:      noarch

%description k8s-yaml
This package contains the yaml file requried to download and run the
weave container in a kubernetes cluster.

weave is a virtual network that gives a subnet to each host for use with
container runtimes.

%prep
%setup -q
rm -rf vendor
tar xf %{SOURCE1}
%patch0 -p1
%patch1 -p1

%build
make %{?_smp_mflags} exes WEAVE_VERSION=%{version}

%install
mkdir -p %{buildroot}/home/weave
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_sysconfdir}
mkdir -p %{buildroot}/weavedb

install -m 0755 prog/weave-kube/launch.sh %{buildroot}/home/weave/
install -m 0755 prog/kube-utils/kube-utils %{buildroot}/home/weave/
install -m 0755 prog/weaver/weaver %{buildroot}/home/weave/
install -m 0755 weave %{buildroot}/home/weave/
install -m 0644 prog/weaver/weavedata.db %{buildroot}/weavedb/
install -m 0755 prog/weaveutil/weaveutil %{buildroot}%{_bindir}
install -m 0755 prog/weave-npc/weave-npc %{buildroot}%{_bindir}
# adjust the path to the ulogd plugins
sed -i -e 's|/usr/lib/ulogd|/usr/lib64/ulogd|g' prog/weave-npc/ulogd.conf
install -m 0644 prog/weave-npc/ulogd.conf %{buildroot}%{_sysconfdir}/ulogd.conf.weave

mkdir -p %{buildroot}%{_datadir}/k8s-yaml/weave
install -m 0644 %{SOURCE2} %{buildroot}%{_datadir}/k8s-yaml/weave/weave.yaml
sed -i -e 's|weaveworks/weave-|registry.opensuse.org/kubic/weave-|g' %{buildroot}%{_datadir}/k8s-yaml/weave/weave.yaml

%files kube
%license LICENSE
/home/weave
%{_bindir}/weaveutil
/weavedb

%files npc
%license LICENSE
%{_bindir}/weave-npc
%config %{_sysconfdir}/ulogd.conf.weave

%files k8s-yaml
%dir %{_datarootdir}/k8s-yaml
%dir %{_datarootdir}/k8s-yaml/weave
%{_datarootdir}/k8s-yaml/weave/weave.yaml

%changelog
* Mon Apr 20 2020 Thorsten Kukuk <kukuk@suse.com>
- Use file requires for modprobe (to be able to use busybox-kmod)
* Fri Mar 27 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.6.2
  - Weave Net can not be used in fastdp mode and always falls back
  - Restrict timeout value passed to pcap library
- Refresh vendor.tar.xz
* Tue Mar 10 2020 kukuk@suse.de
- Fix typo in url
* Mon Mar  9 2020 Thorsten Kukuk <kukuk@suse.com>
- weave-kubic needs modprobe
* Mon Mar  9 2020 Thorsten Kukuk <kukuk@suse.com>
- Update weave to 2.6.1
  - Fix possible deadlock
  - disable-iptables-setup.patch
* Wed Nov  6 2019 kukuk@suse.de
- Update weave to 2.6.0
  - Fix a race condition in Kubernetes addon when reclaiming IP addresses after node deletion #3724, #3716
  - Buffer events so Docker won't drop them, and Weave Net can clean up after dead containers #3432, #3705
  - Weave reconnect occasionally fails after network interface disconnect #3666, #3669, #3676
  - Ingress NetworkPolicy would accepts all traffic when specifying both IPBlock and port #3653, #3654
  - Support both podSelector and namespaceSelector in NetworkPolicy #3312, #3647
  - Only add default-drop egress rule if network policies are in use #3639
  - Manifests use 'apps/v1' rather than deprecated 'apps/v1beta1' #3660
  - Avoid Weave Net pods being evicted by setting priorityClassName: system-node-critical #3697
  - Manifests use recommended DNS policy ClusterFirstWithHostNet #3692
  - Weave Net now tolerates 'NoExecute' taint #3655
  - Allow extra arguments to NetworkPolicy controller to be set in an environment variable #3683
  - Stop reporting a failure to connect to self #3454, #3585
  - Minor reduction in log noise when reclaiming IPs #3710
* Sat Nov  2 2019 kukuk@suse.de
- Update weave.yaml for kubernetes 1.16
* Fri Jul 26 2019 kukuk@suse.de
- Adjust registry path to the official images
* Wed Jul 24 2019 kukuk@suse.de
- Add weave-rpmlintrc. This package contains the content of a
  container image, so yes, this includes the home directory and
  a database.
* Wed Jul 24 2019 kukuk@suse.de
- Initial package
